@@ -24,9 +24,12 @@ else:
 red = (220 / 255, 94 / 255, 139 / 255)
 blue = (0 / 255, 114 / 255, 178 / 255, 0.9)
 orange = (220 / 255, 80 / 255, 20 / 255, 0.9)
-skyblue = "#56B4E9"
-green = (0, 130 / 255, 90 / 255)
-colors = [blue, red, orange, skyblue, green]
+# skyblue = "#56B4E9"
+skyblue = "D3E6F6"  # udir blue
+# green = (0, 130 / 255, 90 / 255)
+# green = "#DDF1E7"  # udir green
+green = "BBE3CE"  # udir green (deeper)
+colors = [blue, red, green, skyblue, orange]
 
 COLORS = {
     "blue": blue,
@@ -254,6 +257,7 @@ def plot_polygon(
     alpha=0.05,
     show_vertices=False,
     ls="-",
+    edges=True,
 ):
     points = [*points]
     points.append(points[0])
@@ -262,7 +266,8 @@ def plot_polygon(
 
     x, y = zip(*points)
     ax.fill(x, y, color=color, alpha=alpha)
-    ax.plot(x, y, color="black", alpha=1, lw=1.5, ls=ls)
+    if edges:
+        ax.plot(x, y, color="black", alpha=1, lw=1.5, ls=ls)
 
     if show_vertices:
         x, y = zip(*set(points))
